@@ -1,10 +1,11 @@
-# Copyright 2021 Google LLC
+# coding=utf-8
+# Copyright 2021 Google LLC..
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,6 +17,7 @@ from google.cloud import translate_v2 as translate
 
 
 class LanguageDetection():
+
   def __init__(self, engine='gcp'):
     self.engine = engine
     if self.engine == 'gcp':
@@ -29,8 +31,7 @@ class LanguageDetection():
     if self.engine == 'gcp':
       result = self.translate_client.detect_language(text)
       # print("Confidence: {}".format(result["confidence"]))
-      language_code = result["language"]
+      language_code = result['language']
     else:
       raise RuntimeError('Unsupported')
     return language_code
-
